==> libgda-0.8.190.tar.gz: libgda-0.8.190/libgda/gda-parameter.h <==
/* GDA library
 * Copyright (C) 1998-2002 The GNOME Foundation.
 *
 * AUTHORS:
 *	Rodrigo Moya <rodrigo@gnome-db.org>
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#if !defined(__gda_parameter_h__)
#  define __gda_parameter_h__

#include <glib/gmacros.h>
#include <libgda/gda-value.h>

G_BEGIN_DECLS

typedef struct {
	gchar *name;
	GdaValue *value;
} GdaParameter;

GdaParameter   *gda_parameter_new (const gchar *name, GdaValueType type);
GdaParameter   *gda_parameter_new_string (const gchar *name, const gchar *value);
void            gda_parameter_free (GdaParameter *param);
const gchar    *gda_parameter_get_name (GdaParameter *param);
void            gda_parameter_set_name (GdaParameter *param, const gchar *name);
const GdaValue *gda_parameter_get_value (GdaParameter *param);
void            gda_parameter_set_value (GdaParameter *param, GdaValue *value);

typedef struct _GdaParameterList GdaParameterList;

GdaParameterList   *gda_parameter_list_new (void);
void                gda_parameter_list_free (GdaParameterList *plist);
void                gda_parameter_list_add_parameter (GdaParameterList *plist,
						      GdaParameter *param);
GdaParameter       *gda_parameter_list_find (GdaParameterList *plist,
					     const gchar *name);
void                gda_parameter_list_clear (GdaParameterList *plist);
guint               gda_parameter_list_get_length (GdaParameterList *plist);

G_END_DECLS

#endif

==> libgda-1.1.3.tar.gz: libgda-1.1.3/libgda/gda-parameter.h <==
/* GDA library
 * Copyright (C) 1998-2002 The GNOME Foundation.
 *
 * AUTHORS:
 *	Rodrigo Moya <rodrigo@gnome-db.org>
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#if !defined(__gda_parameter_h__)
#  define __gda_parameter_h__

#include <glib/gmacros.h>
#include <libgda/gda-value.h>

G_BEGIN_DECLS

typedef struct _GdaParameter GdaParameter;

struct _GdaParameter {
	gchar *name;
	GdaValue *value;
};

#define GDA_TYPE_PARAMETER (gda_parameter_get_type())

GType           gda_parameter_get_type (void);
GdaParameter   *gda_parameter_new_from_value (const gchar *name, GdaValue *value);
GdaParameter   *gda_parameter_new_boolean (const gchar *name, gboolean value);
GdaParameter   *gda_parameter_new_double (const gchar *name, gdouble value);
GdaParameter   *gda_parameter_new_gobject (const gchar *name, const GObject *value);
GdaParameter   *gda_parameter_new_string (const gchar *name, const gchar *value);
GdaParameter   *gda_parameter_copy (GdaParameter *param);
void            gda_parameter_free (GdaParameter *param);
const gchar    *gda_parameter_get_name (GdaParameter *param);
void            gda_parameter_set_name (GdaParameter *param, const gchar *name);
const GdaValue *gda_parameter_get_value (GdaParameter *param);
void            gda_parameter_set_value (GdaParameter *param, GdaValue *value);

typedef struct _GdaParameterList GdaParameterList;

#define GDA_TYPE_PARAMETER_LIST (gda_parameter_list_get_type())

GType               gda_parameter_list_get_type (void);
GdaParameterList   *gda_parameter_list_new (void);
void                gda_parameter_list_free (GdaParameterList *plist);
GdaParameterList   *gda_parameter_list_copy (GdaParameterList *plist);
void                gda_parameter_list_add_parameter (GdaParameterList *plist,
						      GdaParameter *param);
GList              *gda_parameter_list_get_names (GdaParameterList *plist);
GdaParameter       *gda_parameter_list_find (GdaParameterList *plist,
					     const gchar *name);
void                gda_parameter_list_clear (GdaParameterList *plist);
guint               gda_parameter_list_get_length (GdaParameterList *plist);

G_END_DECLS

#endif
